Package: ARPobservation
Title: Tools for Simulating Direct Behavioral Observation Recording
        Procedures Based on Alternating Renewal Processes
Description: Tools for simulating data generated by direct observation
    recording. Behavior streams are simulated based on an alternating renewal
    process, given specified distributions of event durations and interim
    times. Different procedures for recording data can then be applied to the
    simulated behavior streams. Functions are provided for the following
    recording methods: continuous duration recording, event counting, momentary
    time sampling, partial interval recording, whole interval recording, and
    augmented interval recording.
Version: 1.2.2
Maintainer: James E. Pustejovsky <jepusto@gmail.com>
Author: James E. Pustejovsky, with contributions from Daniel M. Swan
License: GPL-3
VignetteBuilder: knitr
Imports: stats
Suggests: shiny, plyr, reshape2, dplyr, ggplot2, viridis, knitr,
        rmarkdown, testthat
RoxygenNote: 7.2.3
Encoding: UTF-8
Language: en-US
NeedsCompilation: no
Packaged: 2023-08-25 16:44:35 UTC; James
Repository: CRAN
Date/Publication: 2023-08-25 17:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 11:29:15 UTC; unix
