# Generated by roxygen2: do not edit by hand

S3method(plot,behavior_stream)
export(ARPsimulator)
export(F_const)
export(F_exp)
export(F_gam)
export(F_gam_mix)
export(F_unif)
export(F_weib)
export(PIR_MOM)
export(PIR_loglik)
export(augmented_recording)
export(continuous_duration_recording)
export(eq_dist)
export(event_counting)
export(incidence_bounds)
export(interim_bounds)
export(interval_recording)
export(logRespRatio)
export(momentary_time_recording)
export(prevalence_bounds)
export(r_AIR)
export(r_MTS)
export(r_PIR)
export(r_WIR)
export(r_behavior_stream)
export(r_continuous_recording)
export(r_event_counting)
export(reported_observations)
