### Behavior change


#### Event behaviors

3. The fourth input box of column one asks you to specify the __percentage change__ in frequency as a result of the treatment, from -100% (i.e., complete extinction) to +100% (doubling the frequency) or more. The default value of 0% corresponds to no change (i.e., a treatment that has no effect at all--neither beneficial nor harmful). It may seem odd to you to have to specify a value for percentage change--after all, the whole point of conducting the study is to see how much the behavior can be changed!--but again, this is just a hypothetical exercise. If you have no sense of how big a change you might see, you might choose a value here by thinking about what the smallest percentage change would be where you would still consider the treatment to be somewhat effective.  
4. The last input in column one asks you to specify the __immediacy__ of the change in behavior by moving the slider bar to the desired level. Possible values range from 0% to 100%, with 100% corresponding to an immediate change and 0% corresponding to a change that takes an infinitely long time to occur. Within this range, the immediacy corresponds to the percentage of the full change that happens in the first treatment session. For example, suppose that the intervention will eventually produce a 90% decrease in the frequency of a behavior. An immediacy of 60% means that the average frequency will decrease by 60% X 90% = 54% during the first treatment session. 

#### State behaviors

* Next, you will need to specify how the average event duration and average interim time change as a result of treatment. Do this by inputting the __percentage change in duration__ and __percentage change in interim time__ in the fourth and fifth boxes of column one, respectively. In order to select sensible values here, you will need to think precisely about how you expect the treatment to impact the behavior. For instance, the treatment might increase the length of time in between episodes of problem behavior (a percentage _increase_ in interim time), but when problem behaviors do occur, the length of each episode might be more or less unchanged (a zero percentage change in duration). Alternately, it may be that the treatment actually reduces the length of episodes of problem behavior (a percentage _decrease_ in event duration).
* Finally, the last input box in column one asks you to specify the __immediacy__ of the change in behavior by moving the slider bar to the desired level. Possible values range from 0% to 100%, with 100% corresponding to an immediate change and 0% corresponding to a change that takes an infinitely long time to occur. Within this range, the immediacy corresponds to the percentage of the full change that happens in the first treatment session. For example, suppose that the intervention will eventually produce a 90% decrease in the duration of a behavior. An immediacy of 60% means that the average duration will decrease by 60% X 90% = 54% during the first treatment session. Note that the simulator assumes that the immediacy of the changes is the same for both duration and interim time.
